#!/bin/bash

ELF_FILENAME="simple_socket_server_plus.elf"
SOF_FILENAME="nios2_linux_3c120_125mhz_top.sof"
CABLE="1"
DEVICE="1"
NIOS2_INSTANCE="0"
JTAG_UART_INSTANCE="0"
SIDP="0x8004d40"
ID="482137343u"
TIMESTAMP="1241815090u"

#
# Verify that the input files specified above actually exist...
#

if [ ! -f ${SOF_FILENAME} ] ; then
	echo ""
	echo "ERROR: the speified SOF file does not appear to exist..."
	echo "SOF file: ${SOF_FILENAME}"
	echo ""

	exit 1
fi

if [ ! -f ${ELF_FILENAME} ] ; then
	echo ""
	echo "ERROR: the speified ELF file does not appear to exist..."
	echo "ELF file: ${ELF_FILENAME}"
	echo ""

	exit 1
fi

echo ""
echo "When this script successfully completes the download and startup of this demo"
echo "it will have leave the nios2-terminal program running to interact with STDIO"
echo "from the demo.  So the output that you see in the shell will be from the Nios"
echo "application and when you type commands in the shell, you will be sending them"
echo "into the Nios application."
echo ""
echo "To terminate the nios2-terminal and exit back into the bash shell that you"
echo "launched this script from, you will need to type CTRL-C."
echo ""
USER_INPUT="NO"
while [ ${USER_INPUT} != "YES" ] ; do

	echo -n "Do you understand the statement above? (Y/N):"
	read USER_INPUT
	case ${USER_INPUT} in
		[Yy])
			echo "Continuing the script..."
			USER_INPUT="YES"
			;;
		[Nn])
			echo "Exiting the script..."
			exit 1
			;;
		*)
			USER_INPUT="NO"
			;;
	esac
done

CMD="nios2-download --cable ${CABLE} --device ${DEVICE} --instance ${NIOS2_INSTANCE} --sidp ${SIDP} --id ${ID} --timestamp ${TIMESTAMP} --reset-target"
echo ""
echo "#"
echo "# Attempting to determine if the FPGA is already configured with this command:"
echo "#"
echo ${CMD}
echo ""

${CMD} || {
	CMD="nios2-configure-sof --cable ${CABLE} --device ${DEVICE} ${SOF_FILENAME}"
	echo ""
	echo "#"
	echo "# Attempting to configure the FPGA with this command:"
	echo "#"
	echo ${CMD}
	echo ""
	
	${CMD} || {
		echo ""
		echo "#"
		echo "# ERROR: while attempting to configure the FPGA..."
		echo "#"
		echo ""
	
		exit 1
	}

	CMD="nios2-download --cable ${CABLE} --device ${DEVICE} --instance ${NIOS2_INSTANCE} --sidp ${SIDP} --id ${ID} --timestamp ${TIMESTAMP} --reset-target"
	echo ""
	echo "#"
	echo "# Attempting to determine if the FPGA is configured properly with this command:"
	echo "#"
	echo ${CMD}
	echo ""

	${CMD} || {
		echo ""
		echo "#"
		echo "# ERROR: cannot verify FPGA contains correct confiuration..."
		echo "#"
		echo ""
	
		exit 1
	}
}

CMD="nios2-download --cable ${CABLE} --device ${DEVICE} --instance ${NIOS2_INSTANCE} --sidp ${SIDP} --id ${ID} --timestamp ${TIMESTAMP} --reset-target ${ELF_FILENAME}"
echo ""
echo "#"
echo "# Attempting to download ELF program with this command:"
echo "#"
echo ${CMD}
echo ""

${CMD} || {
	echo ""
	echo "#"
	echo "# ERROR: While downloading ELF program to Nios II RAM..."
	echo "#"
	echo ""

	exit 1
}

CMD="nios2-download --cable ${CABLE} --device ${DEVICE} --instance ${NIOS2_INSTANCE} --sidp ${SIDP} --id ${ID} --timestamp ${TIMESTAMP} --wait 5 --go"
echo ""
echo "#"
echo "# Attempting to start Nios II in 5 seconds with this command:"
echo "#"
echo ${CMD}
echo ""

${CMD} &

CMD="nios2-terminal --cable ${CABLE} --device ${DEVICE} --instance ${JTAG_UART_INSTANCE} --flush"
echo ""
echo "#"
echo "# Attempting to start nios2-terminal with this command:"
echo "#"
echo ${CMD}
echo ""

${CMD}

exit 0
